slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPGetConvergedReason

Gets the reason why the PEPSolve() iteration was stopped.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPGetConvergedReason(PEP pep,PEPConvergedReason *reason)

Not Collective

### Input Parameter

| pep | - the polynomial eigensolver context

### Output Parameter

| reason | - negative value indicates diverged, positive value converged

### Options Database Key

| -pep_converged_reason | - print the reason to a viewer

### Notes

Possible values for reason are

| PEP_CONVERGED_TOL | - converged up to tolerance
| PEP_CONVERGED_USER | - converged due to a user-defined condition
| PEP_DIVERGED_ITS | - required more than max_it iterations to reach convergence
| PEP_DIVERGED_BREAKDOWN | - generic breakdown in method
| PEP_DIVERGED_SYMMETRY_LOST | - pseudo-Lanczos was not able to keep symmetry

Can only be called after the call to PEPSolve() is complete.

### See Also

PEPSetTolerances(), PEPSolve(), PEPConvergedReason

### Level

intermediate

### Location

src/pep/interface/pepsolve.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages